@@ -1,6 +1,6 @@
 package PMLTQ::Relation::PDT::ALexOrAuxRFIterator;
 our $AUTHORITY = 'cpan:MATY';
-$PMLTQ::Relation::PDT::ALexOrAuxRFIterator::VERSION = '2.0.2';
+$PMLTQ::Relation::PDT::ALexOrAuxRFIterator::VERSION = '3.0.1';
 # ABSTRACT: a/lex.rf or a/aux.rf relation iterator for PDT like treebanks
 
 use strict;
@@ -18,6 +18,17 @@ use PMLTQ::Relation {
   test_code        => q(grep($_ eq $end->{id}, PMLTQ::Relation::PDT::TGetANodeIDs($start)) ? 1 : 0),
 };
 
+BEGIN {
+  {
+    local $@; # protect existing $@
+    eval {
+      require PMLTQ::PML2BASE::Relation::PDT::ALexOrAuxRFIterator;
+      PMLTQ::PML2BASE::Relation::PDT::ALexOrAuxRFIterator->import();
+    };
+    print STDERR "PMLTQ::PML2BASE::Relation::PDT::ALexOrAuxRFIterator is not installed\n" if $@;
+  }
+}
+
 
 sub get_node_list {
   my ($self, $node) = @_;
@@ -29,16 +40,7 @@ sub get_node_list {
 sub init_sql {
   my ($table_name, $schema, $desc, $fh) = @_;
 
-  $fh->{'#POST_SQL'}->print(<<"EOF");
-INSERT INTO "${table_name}"
-  SELECT t."#idx" AS "#idx", a."lex" AS "#value"
-    FROM "t-node" t JOIN "t-a" a ON a."#idx"=t."a"
-  UNION
-  SELECT t."#idx" AS "#idx", aux."#value" AS "#value"
-    FROM "t-node" t JOIN "t-a" a ON a."#idx"=t."a" JOIN "t-a/aux.rf" aux ON aux."#idx"=a."aux.rf"
-  UNION
-  SELECT r."#idx" AS "#idx", r."atree" FROM "t-root" r;
-EOF
+  PMLTQ::PML2BASE::Relation::PDT::ALexOrAuxRFIterator::init_sql($table_name, $schema, $desc, $fh);
 }
 
 1;
@@ -55,7 +57,7 @@ PMLTQ::Relation::PDT::ALexOrAuxRFIterator - a/lex.rf or a/aux.rf relation iterat
 
 =head1 VERSION
 
-version 2.0.2
+version 3.0.1
 
 =head1 AUTHORS
 
